UiPath Documentation
automation-suite
2.2510
true
Guía de referencia de uipathctl
Importante :
Este contenido se ha localizado parcialmente a partir de un sistema de traducción automática. La localización de contenidos recién publicados puede tardar entre una y dos semanas en estar disponible.

Paquete de salud de uipathctl

Generar paquete de soporte para solucionar incidencias de Automation Suite.

Descripción​

Genere un paquete de soporte que puede usar para solucionar problemas de Automation Suite .

uipathctl health bundle [PATH] [flags]
uipathctl health bundle [PATH] [flags]

Ejemplos​

# Generate the bundle in the OS temporary directory
uipathctl health bundle input.json --versions versions.json

# Generate the bundle in a specific directory
uipathctl health bundle input.json --versions versions.json --output-dir /foo/bar

# Generate the bundle with historical logs for 2 days from 2021-09-01
uipathctl health bundle input.json --versions versions.json --from 2021-09-01 --days 7 --include historical-logs

# Generate the bundle excluding rke2-bundle
uipathctl health bundle input.json --versions versions.json --exclude rke2-bundle
# Generate the bundle in the OS temporary directory
uipathctl health bundle input.json --versions versions.json

# Generate the bundle in a specific directory
uipathctl health bundle input.json --versions versions.json --output-dir /foo/bar

# Generate the bundle with historical logs for 2 days from 2021-09-01
uipathctl health bundle input.json --versions versions.json --from 2021-09-01 --days 7 --include historical-logs

# Generate the bundle excluding rke2-bundle
uipathctl health bundle input.json --versions versions.json --exclude rke2-bundle

Opciones​

      --days int            Number of days from the start date for which we want to collect the historical logs. (default -1)
      --exclude string      Specify components (comma separated) to exclude from the bundle. For example, --exclude=rke2-bundle
      --from string         Start date to collect the historical logs in YYYY-MM-DD format.
  -h, --help                help for bundle
      --include string      Specify additional components (comma separated) to include in the bundle. For example, --include=historical-logs
      --limit-bytes int     Maximum bytes of logs to return. Defaults to no limit.
      --namespace string    The namespace where UiPath Automation Suite is deployed
      --output-dir string   path to output directory
      --versions string     path to versions file
      --days int            Number of days from the start date for which we want to collect the historical logs. (default -1)
      --exclude string      Specify components (comma separated) to exclude from the bundle. For example, --exclude=rke2-bundle
      --from string         Start date to collect the historical logs in YYYY-MM-DD format.
  -h, --help                help for bundle
      --include string      Specify additional components (comma separated) to include in the bundle. For example, --include=historical-logs
      --limit-bytes int     Maximum bytes of logs to return. Defaults to no limit.
      --namespace string    The namespace where UiPath Automation Suite is deployed
      --output-dir string   path to output directory
      --versions string     path to versions file

Opciones heredadas de los comandos principales​

      --context string      name of the kubeconfig context to use
      --excluded strings    components to be excluded from execution, defaults to none
  -f, --force               override all user prompts to true
      --included strings    components to be included in the execution, defaults to all
      --kubeconfig string   kubectl configuration file (default: ~/.kube/config)
      --log-format string   log format. one of [text,json] (default "text")
      --log-level string    set log level. one of [trace,debug,info,error] (default "info")
  -o, --output output       output format. one of [json,yaml,text,junit] (default text)
  -q, --quiet               suppress all output except for errors and warnings
      --timeout duration    timeout of the command (default: 90 minutes) (default 1h30m0s)
      --context string      name of the kubeconfig context to use
      --excluded strings    components to be excluded from execution, defaults to none
  -f, --force               override all user prompts to true
      --included strings    components to be included in the execution, defaults to all
      --kubeconfig string   kubectl configuration file (default: ~/.kube/config)
      --log-format string   log format. one of [text,json] (default "text")
      --log-level string    set log level. one of [trace,debug,info,error] (default "info")
  -o, --output output       output format. one of [json,yaml,text,junit] (default text)
  -q, --quiet               suppress all output except for errors and warnings
      --timeout duration    timeout of the command (default: 90 minutes) (default 1h30m0s)
  • Descripción​
  • Ejemplos​
  • Opciones​
  • Opciones heredadas de los comandos principales​

¿Te ha resultado útil esta página?

Conectar

¿Necesita ayuda? Soporte

¿Quiere aprender? UiPath Academy

¿Tiene alguna pregunta? Foro de UiPath

Manténgase actualizado